import argparse
from colorama import Fore, init, Style
import requests
import datetime
import pyfiglet
from lolpython import lol_py
import sys


def show_info(uid, reg):
    try:
        ascii_art = pyfiglet.figlet_format("Open-FF")
        lol_py(ascii_art)

        print()
        lol_py("Created by Abdul Moeez. FF UID : 12544204952 : [REG] ~ PK")
        print()

        print(Fore.YELLOW + f"[•] Fetching info of {uid} ...")
        response = requests.get(
            f"https://info-ob49.vercel.app/api/account/?uid={uid}&region={reg}"
        )

        data = response.json()

        print(Fore.BLUE + str(response.status_code))

        for section, value in data.items():
            print(Fore.CYAN + Style.BRIGHT + "\n--- " + section + " ---")

            udt = ""
            if isinstance(value, dict):
                for k, v in value.items():
                    if k in ["lastLoginAt", "createAt"]:
                        dt = datetime.datetime.fromtimestamp(int(v))
                        udt = str(v)
                        v = dt.strftime("%Y-%m-%d %I:%M:%S %p")

                    print(
                        Fore.GREEN + k + " : ",
                        Fore.BLUE + Style.BRIGHT + str(v),
                        Fore.BLUE + Style.BRIGHT + f"   {udt}",
                    )
                    udt = ""
            else:
                print(Fore.GREEN + str(value))

    except Exception:
        print(Fore.RED + Style.BRIGHT + "[!] Info fetching failed due to server load. Try again pls!")
        sys.exit(1)


def main():
    init(autoreset=True)

    parser = argparse.ArgumentParser(description="FF CLI")
    parser.add_argument("uid", type=int, help="FF UID")
    parser.add_argument("--reg", type=str, help="FF UID REGION", default="PK")

    try:
        args = parser.parse_args()
        show_info(args.uid, args.reg)

    except Exception as e:
        print(Fore.RED + Style.BRIGHT + f"[!] ERROR : {e}")
        sys.exit(1)


if __name__ == "__main__":
    main()



import requests
from colorama import init, Fore, Style
import argparse
import pyfiglet
from lolpython import lol_py
import sys

init(autoreset=True)

def main(uid):
    try:
        ascii_art = pyfiglet.figlet_format("Open-FF")
        lol_py(ascii_art)
        print()
        lol_py("Created by Abdul Moeez. FF UID is 12544204952")
        print()
        url = f"https://bancheckbackend.tsunstudio.pw/bancheck?key=saeed&uid={uid}"
        response = requests.get(url)
        print(Fore.YELLOW + "[•] Fetching info ...")

        data = response.json()

        print(Fore.CYAN + Style.BRIGHT + f"[✓] FF UID STATUS : {data['status']}")
        print(Fore.CYAN + Style.BRIGHT + f"[✓] Ban period : {data['ban_period']}")

    except Exception as e:
        print(Fore.RED + f"[!] ERROR : {e}")
        sys.exit(1)

if __name__ == '__main__':
    parser = argparse.ArgumentParser(description="Ban checker")
    parser.add_argument("uid", type=str, help="FF UID", default=404)
    args = parser.parse_args()
    if args.uid == 404:
        print(Fore.BLUE+Style.BRIGHT+"[USAGE] : is_ban <UID>")
        sys.exit(1)
    main(args.uid)



from setuptools import setup, find_packages

setup(
    name="open-freefire",
    version="1.2.0",
    packages=find_packages(),
    entry_points = {
        "console_scripts": ["show_info = OpenFF.cli:main","is_ban = OpenFF.cli2:main"]
    },
    install_requires=[
        "requests",
        "argparse",
        "colorama",
        "datetime",
        "lolpython",
        "pyfiglet"
    ],
    author="Abdul Moeez",
    description="OpenFF: Fetch FF account info and ban status",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://pypi.org/project/open-freefire/",
    python_requires=">=3.7",
)



import requests
import sys

def show_info(uid, reg):
    try:
        print("Created by MOEEZ | FF UID : 12544204952")

        # Type check
        if not isinstance(uid, int):
            raise TypeError(f"{uid} is not int")

        # Length check
        if len(str(uid)) != 11:
            raise Exception(f"{uid} is invalid")

        if not isinstance(reg, str):
            raise TypeError(f"{reg} is not str")

        # Fetch info
        res = requests.get(f"https://info-ob49.vercel.app/api/account/?uid={uid}&region={reg}")
        if not res.ok:
            raise Exception("Info fetching failed, please try again.")

        data = res.json()
        return data

    except Exception as e:
        print(f"OPEN-FF ERR [SHOWINFO] : {e}")
        sys.exit(1)


def is_ban(uid):
    try:
        print("Created by MOEEZ | FF UID : 12544204952")

        # Type check
        if not isinstance(uid, int):
            raise TypeError(f"{uid} is not int")

        # Length check
        if len(str(uid)) != 11:
            raise Exception(f"{uid} is invalid")

        # Fetch ban info
        url = f"https://bancheckbackend.tsunstudio.pw/bancheck?key=saeed&uid={uid}"
        response = requests.get(url)
        if not response.ok:
            raise Exception("Ban checking failed, please try again.")

        data = response.json()
        return data

    except Exception as e:
        print(f"OPEN-FF ERR [ISBAN] : {e}")
        sys.exit(1)
